#include <iostream>
#include <cstdint>
#include <vector>
#include <queue>
#include <algorithm>

struct Vertex;

const uint32_t INF = 1e9;

struct Edge {
	Vertex *v;
	uint32_t c;
	uint32_t rInd;

	Edge &rev();
	Edge(Vertex *v = nullptr, uint32_t c = 0): v(v), c(c) {}
};

struct Vertex {
	std::vector<Edge> edges;
	uint32_t dist;

	void add_edge(Vertex *to, uint32_t c, bool bi) {
		edges.push_back(Edge(to, c));
		to->edges.push_back(Edge(this, bi ? c : 0));

		edges.back().rInd = to->edges.size() - 1;
		to->edges.back().rInd = edges.size() - 1;
	}
};

Edge &Edge::rev() {
	return v->edges[rInd];
}

struct Network {
	std::vector<Vertex> vertices;
	Vertex *src, *sink;
	uint32_t curFlow;

	Network(): curFlow(0) {}

	bool calc_dist();
	uint32_t push_flow(Vertex *v, uint32_t e);

	uint32_t max_flow();
};

bool Network::calc_dist() {
	for (Vertex &v : vertices) {
		v.dist = INF;
	}
	sink->dist = 0;
	std::queue<Vertex*> next;
	next.push(sink);

	while (!next.empty()) {
		Vertex *v = next.front();
		next.pop();
		for (Edge &e : v->edges) {
			if ((e.v->dist == INF) && (e.rev().c > 0)) {
				e.v->dist = v->dist + 1;
				next.push(e.v);
			}
		}
	}
	return src->dist < INF;
}

uint32_t Network::push_flow(Vertex *v, uint32_t cf) {
	if (v == sink) {
		return cf;
	}
	for (Edge &e : v->edges) {
		if ((e.c == 0) || (e.v->dist >= v->dist)) {
			continue;
		}
		uint32_t ee = std::min(e.c, cf);
		uint32_t f = push_flow(e.v, ee);
		if (f) {
			e.c -= f;
			e.rev().c += f;
			return f;
		}
	}
	v->dist = INF;
	return 0;
}

uint32_t Network::max_flow() {
	while (calc_dist()) {
		while (uint32_t f = push_flow(src, INF)) {
			curFlow += f;
		}
	}
	return curFlow;
}

struct Fr {
	uint32_t a, b;
	uint32_t cost;

	Fr (uint32_t a = 0, uint32_t b = 0, uint32_t cost = 0): a(a), b(b), cost(cost) {}
};

Network graph;
std::vector<Fr> fr;
std::vector<std::pair<uint32_t, uint32_t>> cost;

std::vector<std::pair<uint32_t, uint32_t>> queries;
std::vector<uint32_t> qAns;

uint32_t maxPossib;
uint32_t qCnt;

void input() {
	uint32_t vCnt, fCnt;
	std::cin >> vCnt >> fCnt;

	cost.resize(vCnt);
	fr.resize(fCnt);

	for (uint32_t i = 0;i < vCnt;i++) {
		std::cin >> cost[i].first;
	}

	for (uint32_t i = 0;i < vCnt;i++) {
		std::cin >> cost[i].second;
	}

	for (auto &i : fr) {
		std::cin >> i.a >> i.b >> i.cost;
		i.a--;
		i.b--;
	}

	uint32_t qCnt;
	std::cin >> qCnt;
	queries.resize(qCnt);
	for (auto &q : queries) {
		std::cin >> q.first;
		if (q.first < 3) {
			std::cin >> q.second;
		}
	}
}

Network n;

uint32_t add_vertex(uint32_t i, std::vector<bool> &curActive) {
	n.src->add_edge(&n.vertices[i], cost[i].first, false);
	n.vertices[i].add_edge(n.sink, cost[i].second, false);

	for (const auto &j : fr) {
		uint32_t to;
		if (j.a == i) {
			to = j.b;
		} else if (j.b == i) {
			to = j.a;
		} else {
			continue;
		}
		if (curActive[to]) {
			n.vertices[i].add_edge(&n.vertices[to], j.cost, true);
		}
	}
	curActive[i] = true;
	return cost[i].first + cost[i].second;
}

std::vector<bool> active;
uint32_t actProf;

void init_network(const std::vector<bool> &active) {
	actProf = 0;
	n.vertices.clear();
	n.vertices.resize(cost.size() + 2);

	n.sink = &n.vertices[n.vertices.size() - 1];
	n.src = &n.vertices[n.vertices.size() - 2];

	std::vector<bool> cActive(cost.size(), false);

	for (uint32_t i = 0;i < active.size();i++) {
		if (active[i]) {
			actProf += add_vertex(i, cActive);
		}
	}
}

int main() {
	input();
	std::cerr << "input done" << std::endl;
	active = std::vector<bool>(cost.size(), true);
	init_network(active);

	n.max_flow();
	std::cout << actProf - n.curFlow << "\n";
}
