#include <iostream>
#include <cstdint>
#include <vector>
#include <queue>
#include <algorithm>

struct Vertex;

const uint32_t INF = 1e9;

struct Edge {
	Vertex *v;
	uint32_t c;
	uint32_t oc;
	uint32_t rInd;

	Edge &rev();
	Edge(Vertex *v = nullptr, uint32_t c = 0): v(v), c(c), oc(c) {}
};

struct Vertex {
	std::vector<Edge> edges;
	uint32_t dist;
	bool active;

	void add_edge(Vertex *to, uint32_t c, bool bi) {
		edges.push_back(Edge(to, c));
		to->edges.push_back(Edge(this, bi ? c : 0));

		edges.back().rInd = to->edges.size() - 1;
		to->edges.back().rInd = edges.size() - 1;
	}

	Vertex(): active(true) {}

	void deactivate() {
		active = false;
		for (Edge &e : edges) {
			e.c = e.rev().c = 0;
		}
	}
	void activate() {
		active = true;
		for (Edge &e : edges) {
			if (e.v->active) {
				e.c = e.oc;
				e.rev().c = e.rev().oc;
			}
		}
	}
};

Edge &Edge::rev() {
	return v->edges[rInd];
}

struct Network {
	std::vector<Vertex> vertices;
	Vertex *src, *sink;
	uint32_t curFlow;

	Network(): curFlow(0) {}

	bool calc_dist();
	uint32_t push_flow(Vertex *v, uint32_t e);

	uint32_t max_flow();
};

bool Network::calc_dist() {
	for (Vertex &v : vertices) {
		v.dist = INF;
	}
	sink->dist = 0;
	std::queue<Vertex*> next;
	next.push(sink);

	while (!next.empty()) {
		Vertex *v = next.front();
		next.pop();
		for (Edge &e : v->edges) {
			if ((e.v->dist == INF) && (e.rev().c > 0)) {
				e.v->dist = v->dist + 1;
				next.push(e.v);
			}
		}
	}
	return src->dist < INF;
}

uint32_t Network::push_flow(Vertex *v, uint32_t cf) {
	if (v == sink) {
		return cf;
	}
	for (Edge &e : v->edges) {
		if ((e.c == 0) || (e.v->dist >= v->dist)) {
			continue;
		}
		uint32_t ee = std::min(e.c, cf);
		uint32_t f = push_flow(e.v, ee);
		if (f) {
			e.c -= f;
			e.rev().c += f;
			return f;
		}
	}
	v->dist = INF;
	return 0;
}

uint32_t Network::max_flow() {
	while (calc_dist()) {
		while (uint32_t f = push_flow(src, INF)) {
			curFlow += f;
		}
	}
	return curFlow;
}

struct Fr {
	uint32_t a, b;
	uint32_t cost;

	Fr (uint32_t a = 0, uint32_t b = 0, uint32_t cost = 0): a(a), b(b), cost(cost) {}
};

Network graph;
std::vector<Fr> fr;
std::vector<std::pair<uint32_t, uint32_t>> cost;

std::vector<std::pair<uint32_t, uint32_t>> queries;
std::vector<uint32_t> qAns;

uint32_t maxPossib;
uint32_t qCnt;

void input() {
	uint32_t vCnt, fCnt;
	std::cin >> vCnt >> fCnt;

	cost.resize(vCnt);
	fr.resize(fCnt);

	for (uint32_t i = 0;i < vCnt;i++) {
		std::cin >> cost[i].first;
	}

	for (uint32_t i = 0;i < vCnt;i++) {
		std::cin >> cost[i].second;
	}

	for (auto &i : fr) {
		std::cin >> i.a >> i.b >> i.cost;
		i.a--;
		i.b--;
	}

	uint32_t qCnt;
	std::cin >> qCnt;
	queries.resize(qCnt);
	for (auto &q : queries) {
		std::cin >> q.first;
		if (q.first < 3) {
			std::cin >> q.second;
			q.second--;
		}
	}
	queries.insert(queries.begin(), {3, 0});
	queries.push_back({3, 0});
}

Network n;

uint32_t add_vertex(uint32_t i) {
	n.src->add_edge(&n.vertices[i], cost[i].first, false);
	n.vertices[i].add_edge(n.sink, cost[i].second, false);

	for (const auto &j : fr) {
		uint32_t to;
		if (j.a == i) {
			to = j.b;
		} else if (j.b == i) {
			to = j.a;
		} else {
			continue;
		}
		if (to < i) {
			n.vertices[i].add_edge(&n.vertices[to], j.cost, true);
		}
	}
	return cost[i].first + cost[i].second;
}

uint32_t actProf;

void init_network() {
	actProf = 0;
	n.vertices.clear();
	n.vertices.resize(cost.size() + 2);

	n.sink = &n.vertices[n.vertices.size() - 1];
	n.src = &n.vertices[n.vertices.size() - 2];

	for (uint32_t i = 0;i < cost.size();i++) {
		actProf += add_vertex(i);
	}
}


int main() {
	input();
	std::cerr << "input done" << std::endl;
	init_network();

	uint32_t nextQ = 0;
	qAns.resize(queries.size());
	for (uint32_t i = 1;i < queries.size();i++) {
		auto &q = queries[i];
		if ((q.first == 1) || (q.first == 3)) {
			uint32_t nProf = actProf;

			std::vector<uint32_t> deact;
			for (uint32_t j = i - 1;j < i;j--) {
				n.max_flow();
				//std::cerr << j << ": " << n.curFlow << " " << nProf << "\n";
				qAns[j] = nProf - n.curFlow;
				if (j == nextQ) {
					break;
				}
				if (queries[j].first == 2) {
					Vertex &v = n.vertices[queries[j].second];
					if (!v.active) {
						v.activate();
						deact.push_back(queries[j].second);
						nProf += cost[queries[j].second].first + cost[queries[j].second].second;
					}
				} else {
					for (uint32_t k = 0;k < cost.size() / 5;k++) {
						Vertex &v = n.vertices[k];
						if (!v.active) {
							v.activate();
							deact.push_back(k);
							nProf += cost[k].first + cost[k].second;
						}
					}
				}
				
			}
			for (uint32_t j : deact) {
				Vertex &v = n.vertices[j];
				v.deactivate();
			}

			nextQ = i;
			if (q.first == 1) {
				Vertex &v = n.vertices[q.second];
				if (!v.active) {
					actProf += cost[q.second].first + cost[q.second].second;
					v.activate();
				}
				for (uint32_t k = 0;k < cost.size();k++) {
					Vertex &v = n.vertices[k];
					if (v.active) {
						v.activate();
					}
				}
				n.curFlow = 0;
			} else {
				for (uint32_t k = 0;k < cost.size();k++) {
					Vertex &v = n.vertices[k];
					if (!v.active) {
						actProf += cost[k].first + cost[k].second;
					}
					v.activate();
				}
				n.curFlow = 0;
			}
		} else if (q.first == 2) {
			n.vertices[q.second].deactivate();
			actProf -= cost[q.second].first + cost[q.second].second;
		} else {
			for (uint32_t k = 0;k < cost.size() / 5;k++) {
				Vertex &v = n.vertices[k];
				if (v.active) {
					v.deactivate();
					actProf -= cost[k].first + cost[k].second;
				}

			}
		}
	}
	uint32_t nProf = actProf;
	for (uint32_t j = queries.size() - 1;j < queries.size();j--) {
		n.max_flow();
		qAns[j] = nProf - n.curFlow;
		if (j == nextQ) {
			break;
		}
		if (queries[j].first == 2) {
			Vertex &v = n.vertices[queries[j].second];
			if (!v.active) {
				v.activate();
				nProf += cost[queries[j].second].first + cost[queries[j].second].second;
			}
		} else {
			for (uint32_t k = 0;k < cost.size() / 5;k++) {
				Vertex &v = n.vertices[k];
				if (!v.active) {
					v.activate();
					nProf += cost[k].first + cost[k].second;
				}
			}
		}
	}

	std::cout << qAns[0] << "\n";
	for (uint32_t i = 0;i < qAns.size();i++) {
		if (queries[i].first < 3) {
			std::cout << qAns[i] << "\n";
		}
	}

}
